CREATE TABLE applications (
    applications_id serial NOT NULL DEFAULT nextval(('applications_applications_id_seq'::text)::regclass),
    users_id int4 NOT NULL,
    name varchar(255) NOT NULL,
    url varchar(255),
    active int4 NOT NULL DEFAULT 1
);
ALTER TABLE applications ADD CONSTRAINT applications_pkey PRIMARY KEY(applications_id);
CREATE UNIQUE INDEX uni_url4 ON applications (url);
CREATE TABLE applications_dictionary (
    applications_dictionary_id serial NOT NULL DEFAULT nextval(('applications_dictionary_applications_dictionary_id_seq'::text)::regclass),
    users_id int4 NOT NULL,
    dictionary_en_id int4 NOT NULL,
    applications_id int4 NOT NULL
);
ALTER TABLE applications_dictionary ADD CONSTRAINT applications_dictionary_pkey PRIMARY KEY(applications_dictionary_id);
CREATE TABLE applications_users (
    applications_users_id serial NOT NULL DEFAULT nextval(('applications_users_applications_users_id_seq'::text)::regclass),
    users_id int4 NOT NULL,
    applications_id int4 NOT NULL
);
ALTER TABLE applications_users ADD CONSTRAINT applications_users_pkey PRIMARY KEY(applications_users_id);
CREATE TABLE comments (
    comments_id serial NOT NULL DEFAULT nextval(('comments_comments_id_seq'::text)::regclass),
    users_id int4 NOT NULL,
    dictionary_en_id int4 NOT NULL,
    comment text NOT NULL,
    date timestamp DEFAULT ('now'::text)::timestamp without time zone,
    subject text
);
ALTER TABLE comments ADD CONSTRAINT comments_pkey PRIMARY KEY(comments_id);
CREATE TABLE configuration (
    configuration_id serial NOT NULL DEFAULT nextval(('configuration_configuration_id_seq'::text)::regclass),
    name varchar(255) NOT NULL,
    value varchar(255) NOT NULL
);
ALTER TABLE configuration ADD CONSTRAINT configuration_pkey PRIMARY KEY(configuration_id);
CREATE TABLE dictionary_cs (
    dictionary_cs_id serial NOT NULL DEFAULT nextval(('dictionary_cs_dictionary_cs_id_seq'::text)::regclass),
    sources_id int4 NOT NULL,
    states_id int4 NOT NULL,
    users_id int4 NOT NULL,
    dictionary_en_id int4 NOT NULL,
    word varchar(255) NOT NULL,
    description text,
    confirmation int4,
    insert_flag varchar(40),
    insert_date varchar(40)
);
ALTER TABLE dictionary_cs ADD CONSTRAINT dictionary_cs_pkey PRIMARY KEY(dictionary_cs_id);
CREATE TABLE dictionary_cs_history (
    dictionary_cs_history_id serial NOT NULL DEFAULT nextval('dictionary_cs_history_dictionary_cs_history_id_seq'::regclass),
    dictionary_cs_id int4 NOT NULL,
    users_id int4 NOT NULL,
    type varchar(255) NOT NULL,
    date timestamp NOT NULL DEFAULT ('now'::text)::timestamp without time zone
);
ALTER TABLE dictionary_cs_history ADD CONSTRAINT dictionary_cs_history_pkey PRIMARY KEY(dictionary_cs_history_id);
CREATE TABLE dictionary_en (
    dictionary_en_id serial NOT NULL DEFAULT nextval(('dictionary_en_dictionary_en_id_seq'::text)::regclass),
    states_id int4 NOT NULL,
    users_id int4 NOT NULL,
    word varchar(255) NOT NULL,
    confirmation int4,
    comments int2 NOT NULL DEFAULT 1,
    url varchar(255) NOT NULL,
    usages_id int4,
    insert_flag varchar(40),
    insert_date varchar(40)
);
ALTER TABLE dictionary_en ADD CONSTRAINT dictionary_en_pkey PRIMARY KEY(dictionary_en_id);
CREATE TABLE dictionary_en_history (
    dictionary_en_history_id serial NOT NULL DEFAULT nextval('dictionary_en_history_dictionary_en_history_id_seq'::regclass),
    dictionary_en_id int4 NOT NULL,
    users_id int4 NOT NULL,
    type varchar(255) NOT NULL,
    date timestamp NOT NULL DEFAULT ('now'::text)::timestamp without time zone
);
ALTER TABLE dictionary_en_history ADD CONSTRAINT dictionary_en_history_pkey PRIMARY KEY(dictionary_en_history_id);
CREATE TABLE import_preview (
    word_en varchar(255) NOT NULL,
    word_cs varchar(255),
    import_flag varchar(40)
);
CREATE TABLE links (
    links_id serial NOT NULL DEFAULT nextval(('links_links_id_seq'::text)::regclass),
    users_id int4 NOT NULL,
    link text NOT NULL,
    url_link text NOT NULL,
    description text NOT NULL
);
ALTER TABLE links ADD CONSTRAINT links_pkey PRIMARY KEY(links_id);
CREATE TABLE polls (
    polls_id serial NOT NULL DEFAULT nextval(('polls_polls_id_seq'::text)::regclass),
    dictionary_en_id int4 NOT NULL,
    users_id int4 NOT NULL
);
ALTER TABLE polls ADD CONSTRAINT polls_pkey PRIMARY KEY(polls_id);
CREATE TABLE sources (
    sources_id serial NOT NULL DEFAULT nextval(('sources_sources_id_seq'::text)::regclass),
    sources_types_id int4 NOT NULL,
    description text
);
ALTER TABLE sources ADD CONSTRAINT sources_pkey PRIMARY KEY(sources_id);
CREATE TABLE sources_types (
    sources_types_id serial NOT NULL DEFAULT nextval(('sources_types_sources_types_id_seq'::text)::regclass),
    name varchar(255) NOT NULL
);
ALTER TABLE sources_types ADD CONSTRAINT sources_types_pkey PRIMARY KEY(sources_types_id);
CREATE TABLE states (
    states_id serial NOT NULL DEFAULT nextval(('states_states_id_seq'::text)::regclass),
    value varchar(255) NOT NULL,
    name varchar(255) NOT NULL
);
ALTER TABLE states ADD CONSTRAINT states_pkey PRIMARY KEY(states_id);
CREATE TABLE tags (
    tags_id serial NOT NULL DEFAULT nextval(('tags_tags_id_seq'::text)::regclass),
    users_id int4 NOT NULL,
    name varchar(255) NOT NULL,
    url varchar(255)
);
ALTER TABLE tags ADD CONSTRAINT tags_pkey PRIMARY KEY(tags_id);
CREATE UNIQUE INDEX uni_url2 ON tags (url);
CREATE TABLE tags_dictionary (
    tags_dictionary_id serial NOT NULL DEFAULT nextval(('tags_dictionary_tags_dictionary_id_seq'::text)::regclass),
    users_id int4 NOT NULL,
    dictionary_en_id int4 NOT NULL,
    tags_id int4 NOT NULL
);
ALTER TABLE tags_dictionary ADD CONSTRAINT tags_dictionary_pkey PRIMARY KEY(tags_dictionary_id);
CREATE TABLE texts (
    texts_id serial NOT NULL DEFAULT nextval(('texts_texts_id_seq'::text)::regclass),
    users_id int4 NOT NULL,
    text text,
    date time NOT NULL
);
ALTER TABLE texts ADD CONSTRAINT texts_pkey PRIMARY KEY(texts_id);
CREATE TABLE usages_types (
    usages_types_id serial NOT NULL DEFAULT nextval(('usages_types_usages_types_id_seq'::text)::regclass),
    name varchar(255) NOT NULL
);
ALTER TABLE usages_types ADD CONSTRAINT usages_types_pkey PRIMARY KEY(usages_types_id);
CREATE TABLE users (
    users_id serial NOT NULL DEFAULT nextval(('users_users_id_seq'::text)::regclass),
    login varchar(255) NOT NULL,
    pass varchar(32) NOT NULL,
    firstname varchar(255) NOT NULL,
    lastname varchar(255) NOT NULL,
    email varchar(255) NOT NULL,
    email_pub bool NOT NULL,
    homepage varchar(255) NOT NULL,
    description text NOT NULL,
    rights int4 NOT NULL DEFAULT 1,
    active int2 NOT NULL DEFAULT 1,
    active_code varchar(255) NOT NULL DEFAULT 'ACTIVATED'::character varying
);
ALTER TABLE users ADD CONSTRAINT users_pkey PRIMARY KEY(users_id);
CREATE TABLE votes (
    votes_id serial NOT NULL DEFAULT nextval(('votes_votes_id_seq'::text)::regclass),
    dictionary_cs_id int4 NOT NULL,
    vote float8 NOT NULL,
    weight float8 NOT NULL,
    users_id int4 NOT NULL
);
ALTER TABLE votes ADD CONSTRAINT votes_pkey PRIMARY KEY(votes_id);
ALTER TABLE applications ADD CONSTRAINT fk_users_id FOREIGN KEY () REFERENCES users() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE applications_dictionary ADD CONSTRAINT ERRELSYS_0 FOREIGN KEY () REFERENCES users() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE applications_users ADD CONSTRAINT fk_applications_id FOREIGN KEY () REFERENCES applications() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE applications_users ADD CONSTRAINT ERRELSYS_1 FOREIGN KEY () REFERENCES users() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE comments ADD CONSTRAINT ERRELSYS_2 FOREIGN KEY () REFERENCES users() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE dictionary_cs_history ADD CONSTRAINT fk_history_cs_dictionary_cs_id FOREIGN KEY () REFERENCES dictionary_cs() ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE dictionary_cs_history ADD CONSTRAINT fk_history_cs_users_id FOREIGN KEY () REFERENCES users() ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE dictionary_en_history ADD CONSTRAINT fk_history_en_dictionary_en_id FOREIGN KEY () REFERENCES dictionary_en() ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE dictionary_en_history ADD CONSTRAINT fk_history_en_users_id FOREIGN KEY () REFERENCES users() ON DELETE CASCADE ON UPDATE CASCADE;
ALTER TABLE links ADD CONSTRAINT ERRELSYS_3 FOREIGN KEY () REFERENCES users() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE polls ADD CONSTRAINT ERRELSYS_4 FOREIGN KEY () REFERENCES users() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE tags ADD CONSTRAINT ERRELSYS_5 FOREIGN KEY () REFERENCES users() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE tags_dictionary ADD CONSTRAINT fk_tags_id FOREIGN KEY () REFERENCES tags() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE tags_dictionary ADD CONSTRAINT ERRELSYS_6 FOREIGN KEY () REFERENCES users() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE texts ADD CONSTRAINT ERRELSYS_7 FOREIGN KEY () REFERENCES users() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE votes ADD CONSTRAINT fk_dictionary_cs_id FOREIGN KEY () REFERENCES dictionary_cs() ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER TABLE votes ADD CONSTRAINT ERRELSYS_8 FOREIGN KEY () REFERENCES users() ON DELETE NO ACTION ON UPDATE NO ACTION;
